pub struct OrderedSet<K> { /* private fields */ }Expand description
Efficient Ordered Set implementatoin that keeps track of the order of insertions and deletions.
Every operation is O(1).
Implementations
Sourceimpl<K> OrderedSet<K>
impl<K> OrderedSet<K>
pub fn new() -> Self
pub fn first(&self) -> Option<&K>
Sourcepub fn insert(&mut self, key: K) -> bool
pub fn insert(&mut self, key: K) -> bool
Insert a key into the set.
Returns true if the key was already present in the set.
Sourcepub fn pop_next(&mut self) -> Option<K>
pub fn pop_next(&mut self) -> Option<K>
Pops the next element inserted into the set.
Returns None if the set is empty.
Sourcepub fn remove(&mut self, key: &K) -> bool
pub fn remove(&mut self, key: &K) -> bool
Removes a key from the set.
Returns true if the key was present in the set.
Sourcepub fn iter(&self) -> OrderedSetIter<'_, K> ⓘ
pub fn iter(&self) -> OrderedSetIter<'_, K> ⓘ
Returns an iterator over the keys in the set.
pub fn len(&self) -> usize