pub struct Block {
pub slot: Slot,
/* private fields */
}Expand description
Block under construction
Fields
slot: SlotImplementations
Sourceimpl Block
State machine for buffering blockstore events based on linger and other buffering limits.
impl Block
State machine for buffering blockstore events based on linger and other buffering limits.
Implements a sans-IO API for better easier testability and better separation of concerns.
If you want to use this in a real-world scenario, you need to implement your own sync/async driver to progress in the same machine.