BlockMachineOutput

Enum BlockMachineOutput 

pub enum BlockMachineOutput<EventStore> {
    FrozenBlock(Block<EventStore>),
    SlotCommitmentUpdate(SlotCommitmentStatusUpdate),
    ForkDetected(ForkDetected),
    DeadBlockDetected(DeadBlockDetected),
}
The different types of outputs produced by the Dragon’s mouth block machine.

Variants



FrozenBlock(Block<EventStore>)

A fully reconstructed block, ready for processing.



SlotCommitmentUpdate(SlotCommitmentStatusUpdate)

An update on the commitment status of a slot. Note: This is sent when the slot reaches or exceeds the minimum commitment level set during initialization. It is guaranteed that the block for this slot has been sent before this update.



ForkDetected(ForkDetected)

A notification that a fork has been detected.



DeadBlockDetected(DeadBlockDetected)

A notification that a dead block has been detected. Note: All Dead blocks are Forks, but not all Forks are Dead blocks. Dead blocks mostly come from corrupted entries early in the replay process of a slot.