pub struct SimpleBlockStore<E> {
pub slot: Slot,
pub events: Vec<E>,
pub account_idx_map: Vec<usize>,
pub transaction_idx_map: Vec<usize>,
pub entry_idx_map: Vec<usize>,
pub other_idx_map: Vec<usize>,
}Fields
slot: Slotevents: Vec<E>account_idx_map: Vec<usize>transaction_idx_map: Vec<usize>entry_idx_map: Vec<usize>other_idx_map: Vec<usize>Trait Implementations
Sourceimpl<E> BlockEventStore for SimpleBlockStore<E>
impl<E> BlockEventStore for SimpleBlockStore<E>
type EventT = E
type Iter<'a> = SimpleBlockStoreIter<'a, E> where Self: 'a, E: 'a
type IntoIter = IntoIter<E>
fn len(&self) -> usize
fn iter(&self) -> Self::Iter<'_>
Sourcefn account_iter(&self) -> Self::Iter<'_>
fn account_iter(&self) -> Self::Iter<'_>
Returns an iterator over the events in this block that are accounts.
Sourcefn transaction_iter(&self) -> Self::Iter<'_>
fn transaction_iter(&self) -> Self::Iter<'_>
Returns an iterator over the events in this block that are transactions.
Sourcefn entry_iter(&self) -> Self::Iter<'_>
fn entry_iter(&self) -> Self::Iter<'_>
Returns an iterator over the events in this block that are entries.
Sourcefn other_iter(&self) -> Self::Iter<'_>
fn other_iter(&self) -> Self::Iter<'_>
Returns an iterator over the events in this block that are neither accounts, transactions, nor entries.
Sourcefn account_len(&self) -> usize
fn account_len(&self) -> usize
Returns the number of account events in this block.
Sourcefn transaction_len(&self) -> usize
fn transaction_len(&self) -> usize
Returns the number of transaction events in this block.
Sourcefn other_len(&self) -> usize
fn other_len(&self) -> usize
Returns the number of events in this block that are neither accounts, transactions, nor entries.
fn into_iter(self) -> Self::IntoIter
fn is_empty(&self) -> bool