pub enum BlockStateMachineOutput {
FrozenBlock(FrozenBlock),
SlotStatus(SlotCommitmentStatusUpdate),
ForksDetected(ForkDetected),
DeadSlotDetected(DeadBlockDetected),
BankCreated(Slot),
BankReset(Slot),
}Variants
FrozenBlock(FrozenBlock)
SlotStatus(SlotCommitmentStatusUpdate)
ForksDetected(ForkDetected)
DeadSlotDetected(DeadBlockDetected)
BankCreated(Slot)
BankReset(Slot)
Given that Anza did not expose any information about the duplicate-unconfirmed-slot scenario, we have to assume that it can happen and the only way to detect it is via a second BankCreated event for the same slot number.
Implementations