BlocksStateMachineWrapper

Struct BlocksStateMachineWrapper 

pub struct BlocksStateMachineWrapper {
    pub sm: BlocksStateMachine,
    /* private fields */
}
The core state machine that processes incoming Geyser events and produces block machine outputs.

Mainly a Wrapper to translate Grpc events to State Machine events.

Fields

sm: BlocksStateMachine

Implementations

Source

impl BlocksStateMachineWrapper

pub fn new() -> Self

pub fn new_with_slot_gc_tracing() -> Self

pub fn pop_slot_gc_trace(&mut self) -> Option<Slot>

Pops the next slot that has been garbage collected by the state machine, if slot GC tracing is enabled.

pub fn handle_block_entry( &mut self, entry: EntryEvInfo, ) -> Result<(), UntrackedSlot>

pub fn handle_slot_update( &mut self, slot_update: SlotUpdateEvInfo, ) -> Result<(), UntrackedSlot>

pub fn handle_block_meta( &mut self, block_meta: BlockMetaEvInfo, ) -> Result<(), UntrackedSlot>

pub fn pop_next_state_machine_output( &mut self, ) -> Option<BlockStateMachineOutput>

pub fn fork_graph(&self) -> &Forks<Slot>

pub fn pop_next_dlq(&mut self) -> Option<DeadletterEvent>

pub fn handle_new_geyser_event( &mut self, event: GeyserEventInfo, ) -> Result<(), UntrackedSlot>